@@ -12,14 +12,14 @@ class TestInitDomain(TestBase):
 
 	@staticmethod
 	def test():
-		import os
+		from subprocess import Popen, PIPE
 
 		contextok = False
 
-		(getin, getout, geterr) = os.popen3("getfilecon /proc/1")
-		getin.close()
+		pipe = Popen("getfilecon /proc/1", shell=True, stdin=PIPE, stdout=PIPE, stderr=PIPE, close_fds=True)
+		pipe.stdin.close()
 
-		for line in getout.readlines():
+		for line in pipe.stdout.readlines():
 			line = line.rstrip()
 			if line == "": continue
 			if line.endswith(":system_r:init_t") \
@@ -27,12 +27,12 @@ class TestInitDomain(TestBase):
 				contextok = True
 			else:
 				print "..%s.." % line
-		getout.close()
+		pipe.stdout.close()
 
-		for line in geterr.readlines():
+		for line in pipe.stderr.readlines():
 			if line.find("failed") >= 0:
 				contextok = "failed"
-		geterr.close()
+		pipe.stderr.close()
 
 		if contextok == "failed":
 			return [TestInitDomain.ErrorGetfileconFailed()]
