@@ -16,13 +16,13 @@ class TestNoKernelT(TestBase):
 
 	@staticmethod
 	def test():
-		import os
+		from subprocess import Popen, PIPE
 
 		badprocs = []
 
-		(getin, getout) = os.popen2("getfilecon /proc/[0-9]*")
-		getin.close()
-		for line in getout.readlines():
+		pipe = Popen("getfilecon /proc/[0-9]*", shell=True, stdin=PIPE, stdout=PIPE, close_fds=True)
+		pipe.stdin.close()
+		for line in pipe.stdout.readlines():
 			(dir, context) = line.split()
 			components = dir.split("/")
 			pid = components[-1]
@@ -34,7 +34,7 @@ class TestNoKernelT(TestBase):
 				file.close()
 				if badproc:
 					badprocs.append(pid)
-		getout.close()
+		pipe.stdout.close()
 		if len(badprocs) > 0:
 			return [TestNoKernelT.ErrorBadKernelProcesses(badprocs)]
 		return []
